# PowerShell script by Carl Barnes - Version 2 - 08/07/22
# View Registry Explorer Preview "PerceivedType" for Clarion Extensions (.clw .inc ... etc)
# to have an idea if they already have a "PerceivedType" defined that is not "text"
#-----------------------------------------------------------------------------------------
# Save this with the PowerShell extension .PS1" e.g. "ExplorerPreviewClarion-View.PS1"
# In Windows Explorer right-click and select "Run with PowerShell"
#-----------------------------------------------------------------------------------------

function See-PerceivedType {
  Param( [string] $DotExten )
  ECHO "========================================================================"
  try 
  {
#    Get-ItemProperty -path "Registry::HKEY_CLASSES_ROOT\$DotExten" -Name PerceivedType
    $PType = (get-itemproperty -path "Registry::HKEY_CLASSES_ROOT\$DotExten" -Name PerceivedType)
    ECHO ($DotExten + " -- See PerceivedType -- " + $DotExten + " --" )
    ECHO $PType
  }
  catch  [System.Management.Automation.PSArgumentException]
    { ECHO ($DotExten + " -- Error: Value PerceivedType does NOT exist for CLASSES_ROOT\" + $DotExten ) }
  catch  [System.Management.Automation.ItemNotFoundException]
   { ECHO ($DotExten + " -- Error: Registry does NOT have Key CLASSES_ROOT\" + $DotExten ) }  
  catch 
    { ECHO ($DotExten + " -- Error: Get-ItemProperty failed for CLASSES_ROOT\" + $DotExten + "  " + $Error[0] ) }
}
##################### End See-PerceivedType #####################

$ErrorActionPreference = "stop"  #so Try/Catch works, alternate is parm: -ErrorAction Stop

See-PerceivedType '.clw'      # Clarion Source CLW
See-PerceivedType '.inc'      # Clarion Include, already Text on mine
See-PerceivedType '.int'      # Clarion Interface 
See-PerceivedType '.equ'      # Clarion Equates
See-PerceivedType '.trn'      # Clarion Translate

See-PerceivedType '.sln'      # VS Solution, not that useful 
See-PerceivedType '.cwproj'   # Clarion Project C7+ IDE

See-PerceivedType '.txa'      # Clarion APP Export
See-PerceivedType '.apv'      # Clarion APP for Version Control same as TXA a text form of an APP

See-PerceivedType '.tpl'      # Clarion Template
See-PerceivedType '.tpw'      # Clarion Template

See-PerceivedType '.c'    # .C file was defined as Text on my machine

# See-PerceivedType '.ps1'  # PowerShell scripts not defined
# See-PerceivedType '.sql'  # .SQL files should be defined as Text
# See-PerceivedType '.a'  # .A has Key but no PerceivedType so tests Catch PSArgumentException

See-PerceivedType '.xml'    # .xml ??

#-----------------------------------------------------------------------------#
# Version 2 - 08/07/22 - Added: .prj .pr .exp .msbuild  .txd .dctx .dcv  
See-PerceivedType '.prj'      # Clarion Project C6-
See-PerceivedType '.pr'       # Clarion Project Hand Coded 
See-PerceivedType '.exp'      # Clarion Lib Definition
See-PerceivedType '.msbuild'  # Microsoft Build an XML file
See-PerceivedType '.txd'      # Clarion DCT Export C6-
See-PerceivedType '.dctx'     # Clarion DCT Export C7+
See-PerceivedType '.dcv'      # Clarion DCT for Version Control same as DCTX a text form of a DCT

# See-PerceivedType '.manifest' # Project Manifest - !!! Returned "System" so do NOT change to "text" 

ECHO "========================================================================"
pause
exit
